==> spring-boot-ext-1.2.282-sources.jar: cn/com/duibaboot/ext/autoconfigure/cat/SleuthMongodbPlugin.java <==
package cn.com.duibaboot.ext.autoconfigure.cat;

import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.reflect.MethodSignature;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.sleuth.ErrorParser;
import org.springframework.cloud.sleuth.Span;
import org.springframework.cloud.sleuth.Tracer;

@Aspect
public class SleuthMongodbPlugin {

    @Autowired
    private Tracer tracer;
    @Autowired
    private ErrorParser errorParser;

    /**
     * 拦截MongoOperations类所有接口，记录执行耗时
     *
     * @param joinPoint
     * @return
     * @throws Throwable
     */
    @Around("execution(* org.springframework.data.mongodb.core.MongoOperations.*(..))")
    public Object springDataMongodbJoinPoint(ProceedingJoinPoint joinPoint) throws Throwable {
        MethodSignature signature = (MethodSignature) joinPoint.getSignature();
        String methodName = signature.getMethod().getName();
        Class<?> clazz = joinPoint.getTarget().getClass();

        if(!tracer.isTracing() || !tracer.getCurrentSpan().isExportable()){
            return joinPoint.proceed();
        }

        Span span = tracer.createSpan("mongodb:/"+methodName);
        StringBuilder stringBuilder = new StringBuilder();
        stringBuilder.append(clazz.getSimpleName()).append(".").append(methodName);
        try {
            span.tag("mongodb.class_method", stringBuilder.toString());// get/...
            span.tag(Span.SPAN_LOCAL_COMPONENT_TAG_NAME, "mongodb");//本地组件名
            span.tag(Span.SPAN_PEER_SERVICE_TAG_NAME, "Mongodb");//远程服务名
            span.logEvent(Span.CLIENT_SEND);

            return joinPoint.proceed();
        } catch(Exception e){
            errorParser.parseErrorTags(span, e);
            throw e;
        } finally {
            span.logEvent(Span.CLIENT_RECV);
            this.tracer.close(span);
        }

    }
}

==> spring-boot-ext-1.3.39-sources.jar: cn/com/duibaboot/ext/autoconfigure/cat/SleuthMongodbPlugin.java <==
package cn.com.duibaboot.ext.autoconfigure.cat;

import cn.com.duiba.boot.perftest.PerfTestContext;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.reflect.MethodSignature;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.sleuth.ErrorParser;
import org.springframework.cloud.sleuth.Span;
import org.springframework.cloud.sleuth.Tracer;

@Aspect
public class SleuthMongodbPlugin {

    @Autowired
    private Tracer tracer;
    @Autowired
    private ErrorParser errorParser;

    /**
     * 拦截MongoOperations类所有接口，记录执行耗时
     *
     * @param joinPoint
     * @return
     * @throws Throwable
     */
    @Around("execution(* org.springframework.data.mongodb.core.MongoOperations.*(..))")
    public Object springDataMongodbJoinPoint(ProceedingJoinPoint joinPoint) throws Throwable {
        MethodSignature signature = (MethodSignature) joinPoint.getSignature();
        String methodName = signature.getMethod().getName();
        Class<?> clazz = joinPoint.getTarget().getClass();

        if(!tracer.isTracing()){
            return joinPoint.proceed();
        }

        Span span = tracer.createSpan("mongodb:/"+methodName);
        StringBuilder stringBuilder = new StringBuilder();
        stringBuilder.append(clazz.getSimpleName()).append(".").append(methodName);
        try {
            if(span.isExportable()) {
                span.tag("mongodb.class_method", stringBuilder.toString());// get/...
                span.tag(Span.SPAN_LOCAL_COMPONENT_TAG_NAME, "mongodb");//本地组件名
                span.tag(Span.SPAN_PEER_SERVICE_TAG_NAME, "Mongodb");//远程服务名
                span.tag("isPerfTest", Boolean.toString(PerfTestContext.isCurrentInPerfTestMode()));
                span.tag("thread", Thread.currentThread().getName());
            }
            span.logEvent(Span.CLIENT_SEND);

            return joinPoint.proceed();
        } catch(Exception e){
            errorParser.parseErrorTags(span, e);
            throw e;
        } finally {
            span.logEvent(Span.CLIENT_RECV);
            this.tracer.close(span);
        }

    }
}
